:mod:`Arithmetique` --- Fonctions arithmétiques
===============================================
Le module :mod:`Arithmetique`


.. automodule:: pyromaths.outils.Arithmetique
    :members:
    :special-members:
    :undoc-members:
..    :private-members:
      :show-inheritance:
